aboutsummaryrefslogtreecommitdiffstats
path: root/kernel
diff options
context:
space:
mode:
authorAndrew Morton <akpm@osdl.org>2004-05-14 05:49:38 -0700
committerLinus Torvalds <torvalds@ppc970.osdl.org>2004-05-14 05:49:38 -0700
commit9cb51c16101578dfa7399833c0282126c50fafc9 (patch)
tree8fff3b3967dad31c9928d708188e7e376497567c /kernel
parent1b9407d76c0cb2e46ae7abc53de35fa91626bd7d (diff)
downloadhistory-9cb51c16101578dfa7399833c0282126c50fafc9.tar.gz
[PATCH] s390: core
From: Martin Schwidefsky <schwidefsky@de.ibm.com> s390 core changes: - Rename idle_cpu_mask to nohz_cpu_mask as agreed with Dipankar. - Refine compiler version check for "Q" constraints in uaccess.h. - Store per process ptrace information to the correct place. - Fix per cpu data access for 64-bit modules. - Add topology_init function for cpu hotplug. - Define TASK_SIZE dependent on TIF_31BIT and define MM_VM_SIZE to 4TB to get rid of elf_map32 and arch_get_unmapped_area.
Diffstat (limited to 'kernel')
-rw-r--r--kernel/rcupdate.c2
-rw-r--r--kernel/sched.c6
2 files changed, 4 insertions, 4 deletions
diff --git a/kernel/rcupdate.c b/kernel/rcupdate.c
index 30253c75aaeaaa..13a1b5a5825f69 100644
--- a/kernel/rcupdate.c
+++ b/kernel/rcupdate.c
@@ -113,7 +113,7 @@ static void rcu_start_batch(long newbatch)
return;
}
/* Can't change, since spin lock held. */
- active = idle_cpu_mask;
+ active = nohz_cpu_mask;
cpus_complement(active);
cpus_and(rcu_ctrlblk.rcu_cpu_mask, cpu_online_map, active);
}
diff --git a/kernel/sched.c b/kernel/sched.c
index fa73c9675abc41..e2b7e89d709d63 100644
--- a/kernel/sched.c
+++ b/kernel/sched.c
@@ -3231,13 +3231,13 @@ void __devinit init_idle(task_t *idle, int cpu)
}
/*
* In a system that switches off the HZ timer idle_cpu_mask
* indicates which cpus entered this state. This is used
* in the rcu update to wait only for active cpus. For system
* which do not switch off the HZ timer idle_cpu_mask should
* always be CPU_MASK_NONE.
*/
-cpumask_t idle_cpu_mask = CPU_MASK_NONE;
+cpumask_t nohz_cpu_mask = CPU_MASK_NONE;
#ifdef CONFIG_SMP
/*
@@ -3231,13 +3231,13 @@ void __devinit init_idle(task_t *idle, int cpu)
}
/*
- * In a system that switches off the HZ timer idle_cpu_mask
+ * In a system that switches off the HZ timer nohz_cpu_mask
* indicates which cpus entered this state. This is used
* in the rcu update to wait only for active cpus. For system
@@ -3231,13 +3231,13 @@ void __devinit init_idle(task_t *idle, int cpu)
* indicates which cpus entered this state. This is used
* in the rcu update to wait only for active cpus. For system
- * which do not switch off the HZ timer idle_cpu_mask should
+ * which do not switch off the HZ timer nohz_cpu_mask should
* always be CPU_MASK_NONE.
*/